============
miraclelight
============

The Python TestRunner by battle heroine "Pretty Cure".

Press enter and cheer them up!

Requirements
============

- Python 3.3

Installation
============

::

   $ git clone git@github.com:drillbits/miraclelight.git
   $ cd miraclelight
   $ python setup.py install

or

::

   $ pip install miraclelight

Usage
=====

Use the miraclelight command.

::

   $ miraclelight

or

::

   $ miraclelight discover -s <start discovery>

After that, test will run but stop soon.

::

   ライトをふって　プリキュアを　おうえんしてね！(Press enter, enter, enter)
   ( ^q^)ﾉｼ

You see, press enter instead of shaking miraclelight and cheer Pretty Cures up.

It defeats 1 test case per 10 enters.

::

   ライトをふって　プリキュアを　おうえんしてね！(Press enter, enter, enter)
   .( ^q^)ﾉｼ

::

   ライトをふって　プリキュアを　おうえんしてね！(Press enter, enter, enter)
   ..( ^q^)ﾉｼ

::

   ライトをふって　プリキュアを　おうえんしてね！(Press enter, enter, enter)
   ...( ^q^)ﾉｼ
